Index: /issm/trunk/src/c/objects/Numerics/ElementMatrix.h
===================================================================
--- /issm/trunk/src/c/objects/Numerics/ElementMatrix.h	(revision 6020)
+++ /issm/trunk/src/c/objects/Numerics/ElementMatrix.h	(revision 6021)
@@ -23,5 +23,5 @@
 		int      nrows;
 		int      ncols;
-		bool     square;
+		bool     dofsymmetrical;
 		bool     kff;
 		double*  values;

Index: /issm/trunk/src/c/objects/Numerics/ElementMatrix.cpp
===================================================================
--- /issm/trunk/src/c/objects/Numerics/ElementMatrix.cpp	(revision 6020)
+++ /issm/trunk/src/c/objects/Numerics/ElementMatrix.cpp	(revision 6021)
@@ -26,5 +26,5 @@
 	this->ncols=0;
 	this->values=NULL;
-	this->square=false;
+	this->dofsymmetrical=false;
 	this->kff=false;
 
@@ -68,5 +68,5 @@
 
 	/*General Case: Ke1 and Ke2 are not empty*/
-	if(!Ke1->square || !Ke2->square) ISSMERROR("merging 2 non square matrices not implemented yet");
+	if(!Ke1->dofsymmetrical || !Ke2->dofsymmetrical) ISSMERROR("merging 2 non dofsymmetrical matrices not implemented yet");
 
 	/*Initialize itransformation matrix Ke[P[i]] = Ke2[i]*/
@@ -90,5 +90,5 @@
 	this->nrows=gsize;
 	this->ncols=gsize;
-	this->square=true;
+	this->dofsymmetrical=true;
 	this->kff=Ke1->kff;
 
@@ -195,5 +195,5 @@
 
 	/*get Matrix size and properties*/
-	this->square=true;
+	this->dofsymmetrical=true;
 	this->nrows=GetNumberOfDofs(nodes,numnodes,GsetEnum,approximation);
 	this->ncols=this->nrows;
@@ -223,5 +223,5 @@
 	}
 
 	/*Because this matrix is "square" don't do cols, we can pick them up from the rows: */
 	this->col_fsize=0;
 	this->col_flocaldoflist=NULL;
@@ -268,5 +268,5 @@
 	double* localvalues=NULL;
 
-	if(this->square){
+	if(this->dofsymmetrical){
 		/*only use row dofs to add values into global matrices: */
 		
@@ -309,5 +309,5 @@
 	}
 	else{
-		ISSMERROR(" non square matrix AddToGlobal routine not support yet!");
+		ISSMERROR(" non dofsymmetrical matrix AddToGlobal routine not support yet!");
 	}
 
@@ -334,5 +334,5 @@
 	printf("   nrows: %i\n",nrows);
 	printf("   ncols: %i\n",ncols);
-	printf("   square: %s\n",square?"true":"false");
+	printf("   dofsymmetrical: %s\n",dofsymmetrical?"true":"false");
 	printf("   kff: %s\n",kff?"true":"false");
 
@@ -359,5 +359,5 @@
 	if(row_sglobaldoflist)for(i=0;i<row_ssize;i++)printf("%i ",row_sglobaldoflist[i]); printf("\n");
 
-	if(!square){
+	if(!dofsymmetrical){
 		printf("   col_fsize: %i\n",col_fsize);
 		printf("   col_flocaldoflist (%p): ",col_flocaldoflist);
@@ -381,5 +381,5 @@
 	this->nrows =Ke->nrows;
 	this->ncols =Ke->ncols;
-	this->square=Ke->square;
+	this->dofsymmetrical=Ke->dofsymmetrical;
 	this->kff   =Ke->kff;
 
@@ -223,5 +223,5 @@
 	}
 
-	/*Because this matrix is "square" don't do cols, we can pick them up from the rows: */
+	/*Because this matrix is "dofsymmetrical" don't do cols, we can pick them up from the rows: */
 	this->col_fsize=0;
 	this->col_flocaldoflist=NULL;